"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _reactNative = require("react-native");
const {
  NavigationBar
} = _reactNative.NativeModules;
const navigationHide = async () => {
  if (_reactNative.Platform.OS === 'android') {
    return await NavigationBar.navigationHide();
  }
};
const navigationShow = async () => {
  if (_reactNative.Platform.OS === 'android') {
    return await NavigationBar.navigationShow();
  }
};
const leanBack = async enabled => {
  if (_reactNative.Platform.OS === 'android') {
    const state = typeof enabled === 'boolean' ? enabled : true;
    return await NavigationBar.leanBack(state);
  }
};
const immersive = async () => {
  if (_reactNative.Platform.OS === 'android') {
    return await NavigationBar.immersive();
  }
};
const stickyImmersive = async enabled => {
  if (_reactNative.Platform.OS === 'android') {
    const state = typeof enabled === 'boolean' ? enabled : true;
    return await NavigationBar.stickyImmersive(state);
  }
};
const lowProfile = async enabled => {
  if (_reactNative.Platform.OS === 'android') {
    const state = typeof enabled === 'boolean' ? enabled : true;
    return await NavigationBar.lowProfile(state);
  }
};
const getBarModeTypes = (style, bar) => {
  const modeStyle = style === 'light' ? NavigationBar.LIGHT : style === 'dark' ? NavigationBar.DARK : NavigationBar.NO_MODE;
  const mode = bar === 'navigation' ? NavigationBar.NAVIGATION_BAR : bar === 'status' ? NavigationBar.STATUS_BAR : NavigationBar.NAVIGATION_BAR_STATUS_BAR;
  return {
    modeStyle,
    mode
  };
};
const setBarMode = async (style, bar) => {
  if (_reactNative.Platform.OS === 'android') {
    const {
      modeStyle,
      mode
    } = getBarModeTypes(style, bar);
    return await NavigationBar.setBarMode(modeStyle, mode);
  }
};
const setNavigationColor = async (color, style, bar) => {
  if (_reactNative.Platform.OS === 'android') {
    const {
      modeStyle,
      mode
    } = getBarModeTypes(style, bar);
    return await NavigationBar.setNavigationColor(color === 'translucent' ? 0 : (0, _reactNative.processColor)(color), color === 'translucent', modeStyle, mode);
  }
};
const setNavigationBarDividerColor = async color => {
  if (_reactNative.Platform.OS === 'android') {
    return await NavigationBar.setNavigationBarDividerColor((0, _reactNative.processColor)(color));
  }
};
const setNavigationBarContrastEnforced = async enabled => {
  if (_reactNative.Platform.OS === 'android') {
    const state = typeof enabled === 'boolean' ? enabled : true;
    return await NavigationBar.setNavigationBarContrastEnforced(state);
  }
};
const fullScreen = async enabled => {
  if (_reactNative.Platform.OS === 'android') {
    const state = typeof enabled === 'boolean' ? enabled : true;
    return await NavigationBar.fullScreen(state);
  }
};
const getBarColor = async bar => {
  if (_reactNative.Platform.OS === 'android') {
    const {
      mode
    } = getBarModeTypes('light', bar || 'both');
    const result = await NavigationBar.getBarColor(mode);
    if (mode === NavigationBar.NAVIGATION_BAR_STATUS_BAR) {
      return JSON.parse(result);
    } else {
      return result;
    }
  }
  return '';
};
const setFitsSystemWindows = async enabled => {
  if (_reactNative.Platform.OS === 'android') {
    const state = typeof enabled === 'boolean' ? enabled : true;
    return await NavigationBar.setFitsSystemWindows(state);
  }
};
console.log();
const theme = async barTheme => {
  const scheme = _reactNative.Appearance.getColorScheme();
  const mode = scheme === "dark" ? "dark" : "light";
  setNavigationColor(barTheme.navigation[mode], mode, "both");
  _reactNative.StatusBar.setBackgroundColor(barTheme.navigation[mode], true);
};
var SystemNavigationBar = {
  navigationHide,
  navigationShow,
  leanBack,
  immersive,
  stickyImmersive,
  lowProfile,
  setBarMode,
  setNavigationColor,
  setNavigationBarDividerColor,
  setNavigationBarContrastEnforced,
  fullScreen,
  getBarColor,
  setFitsSystemWindows,
  theme
};
var _default = exports.default = SystemNavigationBar;
//# sourceMappingURL=index.js.map